# Copyright (C) 2013-2023 Bastian Kleineidam
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Test patool list command"""

import unittest
import os
from patoolib import cli
from . import datadir, needs_program


class ArchiveListTest(unittest.TestCase):
    """Test class for patool list command"""

    @needs_program('tar')
    def test_list(self):
        """Run cli function to list a TAR archive."""
        archive = os.path.join(datadir, "t.tar")
        args = ["-vv", "--non-interactive", "list", archive]
        cli.main(args=args)
